set.seed(420620)
############################################################

## USES DATA IN transectcounts.xlsx NOT SIMULATED DATA.


library(readxl) # load the spreadsheet full of transect info
mydata <- as.data.frame(read_xlsx("transectcounts.xlsx",sheet = 1))
# Explore the new object...
names(mydata)
class(mydata)
str(mydata)
head(mydata)

# Prep our data frame so it has the right columns and column names
names(mydata) <- c("Transect ID","Length","Prop1","count1","count2","count")
mydata$Length1 <- mydata$Length * mydata$Prop1/100
mydata$Length2 <- mydata$Length - mydata$Length1
head(mydata)


## Shall we take a look?
library(ggplot2) # install.packages("ggplot2") if necessary
ggplot(mydata, aes(count, fill = Prop1)) + geom_histogram(binwidth=1) + facet_grid(Prop1 ~ .)
## alternatively...
# x11() # try quartz() if on a Mac and x11() doesn't work
#par(mfrow=c(4,1))
#hist(mydata$count[mydata$Prop1==20], breaks=10:max(mydata$count)+0.5, main="Prop1=20%",xlab="Total Count")
#hist(mydata$count[mydata$Prop1==40], breaks=10:max(mydata$count)+0.5, main="Prop1=40%",xlab="Total Count")
#hist(mydata$count[mydata$Prop1==60], breaks=10:max(mydata$count)+0.5, main="Prop1=60%",xlab="Total Count")
#hist(mydata$count[mydata$Prop1==80], breaks=10:max(mydata$count)+0.5, main="Prop1=80%",xlab="Total Count")

############
## EXERCISE:  What are the means and variances for each of these 4 categories of data?
############

## Next we attempt to infer rate1 and rate2 from the data...
#  See http://www.statmethods.net/advstats/glm.html
#  See ?formula for understanding the first argument to glm()

# Suppose r1=r2=r...
fitpois1 <- glm(count ~ Length - 1, data=mydata, family = poisson(link = "identity"))
summary(fitpois1)
confint(fitpois1,level = 0.99)

# Now suppose r1 != r2...
fitpois2 <- glm(count ~ Length1 + Length2 - 1, data=mydata, family = poisson(link = "identity"))
summary(fitpois2)
confint(fitpois2,level = 0.99)

# Now do the same but with a Negative Binomial distribution. 
#   Here the negative binomial has mean = mu, variace = mu + mu^2/theta
#   Where we can model the mean as in Poisson regression: mu = r1*L1 + r2*L2

library(MASS) # load glm.nb into the workspace...
fitnb1 <- glm.nb(count ~ Length - 1, data=mydata, link = identity)
summary(fitnb1)
confint(fitnb1,level = 0.99)
fitnb2 <- glm.nb(count ~ Length1 + Length2 - 1, data=mydata, link = identity)
summary(fitnb2)
confint(fitnb2,level = 0.99)

## Test which model fits best
AIC(fitpois1, fitnb1, fitpois2, fitnb2)        # Which fits the data best? Lower AIC = better
BIC(fitpois1, fitnb1, fitpois2, fitnb2)        # Which fits the data best? Lower BIC = better
anova(fitpois1, fitpois2, test="Chisq") # Are they significantly different?
anova(fitnb1, fitnb2, test="Chisq")

## As a side note, if we really wanted to know whether or not
## our variance > mean (aka 'overdispersion') is somehow significant
## we have two options: fit a 'quasipoisson' model, which is 
## a way of allowing variance larger than the 'mean' via estimating
## a dispersion parameter (dispersion = variance/mean) which 
## should be 1 for true Poisson data. Alternatively, we could 
## use the dispersiontest() for Poisson GLMs in the AER package,
## which calculates this quantity via a different method:
library(AER) # install.packages(AER) if needed...
summary(glm(count ~ Length - 1, data=mydata, family = quasipoisson(link = "identity")))
dispersiontest(fitpois1)
dispersiontest(fitpois2) 

## Let's nicely format the output to summarize our results.
results <- data.frame(Model=c("Pois.1", "Pois.2", "NB.1", "NB.2"), 
                      dAIC=NA, dBIC=NA, AIC=NA, BIC=NA, ChiSQ.pval.1vs2 =NA, dispersion=NA)
results$AIC=AIC(fitpois1, fitpois2, fitnb1, fitnb2)$AIC
results$dAIC=results$AIC - min(results$AIC)
results$BIC=BIC(fitpois1, fitpois2, fitnb1, fitnb2)$BIC
results$dBIC=results$BIC - min(results$BIC)
ppois= anova(fitpois1, fitpois2, test="Chisq")$`Pr(>Chi)`[2]
pnb = anova(fitnb1, fitnb2, test="Chisq")$`Pr(Chi)`[2]
results$ChiSQ.pval.1vs2 = c(ppois,ppois,pnb,pnb)
results$dispersion=c(dispersiontest(fitpois1)$estimate, dispersiontest(fitpois2)$estimate, NA, NA)

## Here's a dataframe summarizing our results
results

## Note our best model for this data set is the negative binomial model with 
## different rates for each habitat, with a decent, but not fantastic, p-value.